==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/calculel/utesto.f <==
      SUBROUTINE UTESTO(NOMOBJ,TYPE,REFI,REFR,EPSI,CRIT,IFIC)
      IMPLICIT REAL*8 (A-H,O-Z)
      CHARACTER*24 NOMOBJ
      REAL*8 REFR,EPSI
      CHARACTER*(*) CRIT,TYPE
      INTEGER REFI,IFIC
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 15/06/99   AUTEUR CIBHHLV L.VIVAN 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C     ENTREES:
C        NOMOBJ : NOM DE L'OBJET JEVEUX QUE L'ON VEUT TESTER
C        TYPE   : TYPE DE VALEUR A TESTER :
C                  /'RESUME' : ENTIER QUI RESUME L'OBJET
C                  /'S_I'    : SOMME ENTIERE DE L'OBJET
C                  /'S_R'    : SOMME REELLE DE L'OBJET
C        REFI   : VALEUR ENTIERE ATTENDUE POUR L'OBJET
C        REFR   : VALEUR REELLE ATTENDUE POUR L'OBJET
C        CRIT   : 'RELATIF' OU 'ABSOLU'(PRECISION RELATIVE OU ABSOLUE).
C        EPSI   : PRECISION ESPEREE
C        IFIC   : NUMERO LOGIQUE DU FICHIER DE SORTIE
C     SORTIES:
C      LISTING ...
C ----------------------------------------------------------------------
C     VARIABLES LOCALES:
      CHARACTER*3 TYSC
      COMPLEX*16 CBID
      REAL*8 RBID,SOMMR
      INTEGER IBID,RESUME,SOMMI,LONUTI,LONMAX
C
      CALL TSTOBJ(NOMOBJ,RESUME,SOMMI,SOMMR,LONUTI,LONMAX,TYSC,IRET)
      IF (IRET.EQ.0) THEN
        IF (TYPE.EQ.'RESUME') THEN
          CALL UTITES(TYPE,' ','I',REFI,RBID,CBID,RESUME,RBID,CBID,EPSI,
     +                CRIT,IFIC)
        ELSE IF (TYPE.EQ.'S_I') THEN
          CALL UTITES(TYPE,' ','I',REFI,RBID,CBID,SOMMI,RBID,CBID,EPSI,
     +                CRIT,IFIC)
        ELSE IF (TYPE.EQ.'S_R') THEN
          CALL UTITES(TYPE,' ','R',IBID,REFR,CBID,IBID,SOMMR,CBID,EPSI,
     +                CRIT,IFIC)
        END IF
      ELSE
        CALL JEEXIN(NOMOBJ,IRET2)
        IF (IRET2.LE.0) THEN
          WRITE (IFIC,*) ' NOOK OBJET:'//NOMOBJ//' INEXISTANT.'
        ELSE
          WRITE (IFIC,*) ' NOOK OBJET:'//NOMOBJ//' NON TESTABLE.'
        END IF
      END IF
C
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/calculel/utesto.f <==
      SUBROUTINE UTESTO(NOMOBJ,TYPE,REFI,REFR,EPSI,CRIT,IFIC)
      IMPLICIT REAL*8 (A-H,O-Z)
      CHARACTER*24 NOMOBJ
      REAL*8 REFR,EPSI
      CHARACTER*(*) CRIT,TYPE
      INTEGER REFI,IFIC
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 11/01/2005   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
C     ENTREES:
C        NOMOBJ : NOM DE L'OBJET JEVEUX QUE L'ON VEUT TESTER
C        TYPE   : TYPE DE VALEUR A TESTER :
C                  /'RESUME' : ENTIER QUI RESUME L'OBJET
C                  /'S_I'    : SOMME ENTIERE DE L'OBJET
C                  /'S_R'    : SOMME REELLE DE L'OBJET
C        REFI   : VALEUR ENTIERE ATTENDUE POUR L'OBJET
C        REFR   : VALEUR REELLE ATTENDUE POUR L'OBJET
C        CRIT   : 'RELATIF' OU 'ABSOLU'(PRECISION RELATIVE OU ABSOLUE).
C        EPSI   : PRECISION ESPEREE
C        IFIC   : NUMERO LOGIQUE DU FICHIER DE SORTIE
C     SORTIES:
C      LISTING ...
C ----------------------------------------------------------------------
C     VARIABLES LOCALES:
      CHARACTER*3 TYSC
      COMPLEX*16 CBID
      REAL*8 RBID,SOMMR
      INTEGER IBID,RESUME,SOMMI,LONUTI,LONMAX,NI
C
      CALL TSTOBJ(NOMOBJ,'NON',RESUME,SOMMI,SOMMR,LONUTI,LONMAX,TYSC,
     &            IRET,NI)
      IF (IRET.EQ.0) THEN
        IF (TYPE.EQ.'RESUME') THEN
          CALL UTITES(TYPE,' ','I',REFI,RBID,CBID,RESUME,RBID,CBID,EPSI,
     +                CRIT,IFIC)
        ELSE IF (TYPE.EQ.'S_I') THEN
          CALL UTITES(TYPE,' ','I',REFI,RBID,CBID,SOMMI,RBID,CBID,EPSI,
     +                CRIT,IFIC)
        ELSE IF (TYPE.EQ.'S_R') THEN
          CALL UTITES(TYPE,' ','R',IBID,REFR,CBID,IBID,SOMMR,CBID,EPSI,
     +                CRIT,IFIC)
        END IF
      ELSE
        CALL JEEXIN(NOMOBJ,IRET2)
        IF (IRET2.LE.0) THEN
          WRITE (IFIC,*) ' NOOK OBJET:'//NOMOBJ//' INEXISTANT.'
        ELSE
          WRITE (IFIC,*) ' NOOK OBJET:'//NOMOBJ//' NON TESTABLE.'
        END IF
      END IF
C
      END
